@@ -24,46 +24,36 @@
 
 #include "primitivedatainformation.h"
 
-class CharDataInformation: public PrimitiveDataInformation
+class CharDataInformationMethods
 {
-PRIMITIVEDATAINFORMATION_SUBCLASS_CONSTRUCTORS(Char,Primitive)
 public:
-    DATAINFORMATION_CLONE(Char)
-
     static int displayBase();
-    virtual BitCount32 size() const;
-    virtual QString valueString() const;
-    static QString valueString(quint8 value);
-    static quint8 fromVariant(const QVariant& value);
-    virtual AllPrimitiveTypes qVariantToAllPrimitiveTypes(const QVariant& value) const;
-    virtual PrimitiveDataType type() const;
-    virtual AllPrimitiveTypes value() const;
-    virtual void setValue(AllPrimitiveTypes newVal);
+    static QString staticValueString(quint8 value);
+    static quint8 fromVariant(const QVariant& value, bool* ok);
+    static PrimitiveDataType staticType();
     static QScriptValue asScriptValue(quint8 value, QScriptEngine* engine, ScriptHandlerInfo* handler);
-    virtual QScriptValue valueAsQScriptValue() const;
-    virtual QWidget* createEditWidget(QWidget* parent) const;
-    virtual QVariant dataFromWidget(const QWidget* w) const;
-    virtual void setWidgetData(QWidget* w) const;
+
     static QWidget* staticCreateEditWidget(QWidget* parent);
     static QVariant staticDataFromWidget(const QWidget* w);
     static void staticSetWidgetData(quint8 value, QWidget* w);
-private:
-    quint8 mValue;
 };
 
-inline PrimitiveDataType CharDataInformation::type() const
+inline PrimitiveDataType CharDataInformationMethods::staticType()
 {
     return Type_Char;
 }
 
-inline BitCount32 CharDataInformation::size() const
+inline quint8 CharDataInformationMethods::fromVariant(const QVariant& value, bool* ok)
 {
-    return sizeof(quint8) * 8;
-}
-
-inline quint8 CharDataInformation::fromVariant(const QVariant& value)
-{
-    return quint8(value.toUInt());
+    Q_CHECK_PTR(ok);
+    quint32 tmp = value.toUInt(ok);
+    quint8 result = quint8(tmp);
+    if (tmp != quint32(result))
+    {
+        *ok = false; //out of bounds
+        return 0;
+    }
+    return result;
 }
 
 #endif /* CHARDATAINFORMATION_H_ */
