@@ -23,14 +23,21 @@
 
 #include "arrayscriptclass.h"
 #include "../../datatypes/array/arraydatainformation.h"
+#include "../../parsers/parserutils.h"
+#include "../../parsers/scriptvalueconverter.h"
+#include "../scriptlogger.h"
+
+#include <KDebug>
 
 ArrayScriptClass::ArrayScriptClass(QScriptEngine* engine, ScriptHandlerInfo* handlerInfo)
     : DefaultScriptClass(engine, handlerInfo)
 {
-    s_length = engine->toStringHandle(QLatin1String("length"));
+    s_length = engine->toStringHandle(ParserStrings::PROPERTY_LENGTH);
     mIterableProperties.append(qMakePair(s_length, QScriptValue::PropertyFlags(QScriptValue::Undeletable)));
     s_childType = engine->toStringHandle(QLatin1String("childType"));
-    mIterableProperties.append(qMakePair(s_childType, QScriptValue::PropertyFlags(QScriptValue::Undeletable)));
+    //the preferred property (the same as childType)
+    s_type = engine->toStringHandle(ParserStrings::PROPERTY_TYPE);
+    mIterableProperties.append(qMakePair(s_type, QScriptValue::PropertyFlags(QScriptValue::Undeletable)));
 
     mArrayPrototype = engine->newObject();
     mArrayPrototype.setProperty(QLatin1String("toString"), engine->newFunction(Array_proto_toString));
@@ -46,7 +53,7 @@ bool ArrayScriptClass::queryAdditionalProperty(const DataInformation* data, cons
     //no need to modify flags since both read and write are handled
     if (name == s_length)
         return true;
-    else if (name == s_childType)
+    else if (name == s_type || name == s_childType)
         return true;
     else
     {
@@ -66,6 +73,8 @@ bool ArrayScriptClass::additionalPropertyFlags(const DataInformation* data, cons
 {
     Q_UNUSED(data)
     Q_UNUSED(name)
+    if (name == s_childType)
+        return true; //undeleteable is on by default
     if (id != 0)
     {
         *flags |= QScriptValue::ReadOnly;
@@ -81,11 +90,12 @@ QScriptValue ArrayScriptClass::additionalProperty(const DataInformation* data, c
     if (id != 0)
     {
         quint32 pos = id - 1;
-#ifdef OKTETA_DEBUG_SCRIPT
-        kDebug() << "accessing property with id=" << id << "and name=" << name.toString();
-#endif
         if (pos >= data->childCount())
+        {
+            aData->logError() << "attempting to access out of bounds child: index was" << pos
+                    << ", maximum is" << (data->childCount() - 1);
             return engine()->undefinedValue();
+        }
         else
         {
             return aData->childToScriptValue(pos, engine(), mHandlerInfo);
@@ -93,8 +103,13 @@ QScriptValue ArrayScriptClass::additionalProperty(const DataInformation* data, c
     }
     else if (name == s_length)
         return aData->length();
-    else if (name == s_childType)
+    else if (name == s_type)
         return aData->childType();
+    else if (name == s_childType)
+    {
+        aData->logWarn() << "Using property 'childType' is deprecated, use the new name 'type' instead";
+        return aData->childType();
+    }
     return QScriptValue();
 }
 
@@ -103,20 +118,40 @@ bool ArrayScriptClass::setAdditionalProperty(DataInformation* data, const QScrip
     ArrayDataInformation* aData = data->asArray();
     if (name == s_length)
     {
-        if (!value.isNumber())
+        ParsedNumber<uint> newLength = ParserUtils::uintFromScriptValue(value);
+
+        if (!newLength.isValid)
         {
-            engine()->currentContext()->throwError(QScriptContext::TypeError,
-                QLatin1String("Value is not a number: ") + value.toString());
+            aData->logError() << "new length of array is invalid:" << newLength.string;
+            aData->setArrayLength(0);
         }
         else
         {
-            aData->setArrayLength(value.toInt32(), engine()->currentContext());
+            aData->setArrayLength(newLength.value);
         }
         return true;
     }
+    else if (name == s_type)
+    {
+        DataInformation* newChildType = ScriptValueConverter::convert(value,
+                aData->name(), aData->logger(), aData);
+
+        if (!newChildType)
+            aData->logError() << "Failed to parse new child type:" << value.toString();
+        else
+            aData->setArrayType(newChildType);
+        return true;
+    }
     else if (name == s_childType)
     {
-        aData->setArrayType(value, engine()->currentContext());
+        aData->logWarn() << "Using property 'childType' is deprecated, use the new name 'type' instead";
+        DataInformation* newChildType = ScriptValueConverter::convert(value,
+                aData->name(), aData->logger(), aData);
+
+        if (!newChildType)
+            aData->logError() << "Failed to parse new child type:" << value.toString();
+        else
+            aData->setArrayType(newChildType);
         return true;
     }
     return false;
